@@ -326,12 +326,7 @@ def main(args=None):
                 try:
                     import numpy as np
 
-                    model = np.array((f["model_name"]))
-                    try:
-                        u = model.tolist()
-                        model = u.decode()
-                    except:
-                        pass
+                    model = str(np.array((f["model_name"])))
                     patch_size = tuple(f["patch_size"])
                 except KeyError:
                     print("Error on loading model", model_path)
